==> zbxe.beta.0.2.4.tgz: zbxe/modules/admin/lang/jp.lang.php <==
<?php
    /**
     * @file   jp.lang.php
     * @author zero (zero@nzeo.com) 翻訳：RisaPapa
     * @brief  日本語言語パッケージ（基本的な内容のみ）
     **/

    $lang->admin_info = '관리자 정보';
    $lang->admin_index = '관리자 초기 페이지';

    $lang->module_category_title = array(
        'service' => '서비스형 모듈',
        'manager' => '관리형 모듈',
        'utility' => '기능성 모듈',
        'accessory' => '부가 모듈',
        'base' => '기본 모듈',
    );

    $lang->newest_news = "最新ニュース";

    $lang->env_setup = "環境設定";

    $lang->env_information = "환경 정보";
    $lang->current_version = "설치된 버전";
    $lang->current_path = "설치된 경로";
    $lang->released_version = "최신 버전";
    $lang->about_download_link = "설치된 버전보다 최신의 버전이 배포되었습니다. download링크를 클릭하시면 다운 받으실 수 있습니다.";

    $lang->item_module = "モジュールリスト";
    $lang->item_addon  = "アドオンリスト";
    $lang->item_widget = "ウィジェットリスト";
    $lang->item_layout = "レイアウトリスト";

    $lang->module_name = "モジュール名";
    $lang->addon_name = "アドオン名";
    $lang->version = "バージョン";
    $lang->author = "作者";
    $lang->table_count = "テーブル数";
    $lang->installed_path = "インストールパス";

    $lang->cmd_shortcut_management = "メニュー編集";

    $lang->msg_is_not_administrator = '管理者のみ接続できます';
    $lang->msg_manage_module_cannot_delete = 'モジュール、アドオン、ウィジェットのショットカットは削除できません。';
    $lang->msg_default_act_is_null = 'デフォルトの管理者のアクションが指定されていないため、ショットカットを登録することができません。';

    $lang->welcome_to_zeroboard_xe = 'ゼロボードXEの管理者ページです。';
    $lang->about_admin_page = "管理者ページはまだ未完成です。クローズベタバージョンの期間に、多くの方々からご意見をいただきながら、必ず必要なコンテンツを埋めていきたいと思います。";
    $lang->about_lang_env = "위 설정한 언어셋을 처음 방문하는 사용자들에게 동일하게 적용하기 위해서는 원하는 언어로 변경후 아래 [저장] 버튼을 클릭하시면 됩니다";

    $lang->zeroboard_xe_user_links = 'ユーザのためのリンク';
    $lang->zeroboard_xe_developer_links = 'デベロッパーのためのリンク';

    $lang->xe_user_links = array(
        '公式ホームページ' => 'http://www.zeroboard.com',
        //'クローズベタサイト' => 'http://spring.zeroboard.com',
        //'モジュルダ情報' => 'http://www.zeroboard.com',
        //'アドオン情報' => 'http://www.zeroboard.com',
        //'ウィジェット情報' => 'http://www.zeroboard.com',
        //'モジュール・スキン情報' => 'http://www.zeroboard.com',
        //'ウィジェットスキン情報' => 'http://www.zeroboard.com',
        //'レイアウトスキン情報' => 'http://www.zeroboard.com',
    );

    $lang->xe_developer_links = array(
        'デベロッパーフォーラム' => 'http://spring.zeroboard.com',
        //'マニュアル' => 'http://www.zeroboard.com/wiki/manual',
        'イッシュートラッキング' => 'http://trac.zeroboard.com',
        'SVN Repository' => 'http://svn.zeroboard.com',
        'Doxygen Document' => 'http://doc.zeroboard.com',
        'PDFドキュメント' => 'http://doc.zeroboard.com/zeroboard_xe.pdf',
    );

    $lang->zeroboard_xe_usefulness_module = '有用なモジュール';
    $lang->xe_usefulness_modules = array(
        'dispEditorAdminIndex' => 'エディター管理',
        'dispDocumentAdminList' => 'ドキュメント管理',
        'dispCommentAdminList' => 'コメント管理',
        'dispFileAdminList' => '添付ファイル管理',
        'dispPollAdminList' => 'アンケート管理',
        'dispSpamfilterAdminConfig' => 'スパムフィルター管理',
        'dispCounterAdminIndex' => 'カウンターログ',

    );

    $lang->xe_license = 'ゼロボードXEのライセンスはGPLです。';
    $lang->about_shortcut = 'よく使用するモジュールに登録されたショットカットは削除できます。';
?>

==> zbxe.beta.0.2.6.tgz: zbxe/modules/admin/lang/jp.lang.php <==
<?php
    /**
     * @file   jp.lang.php
     * @author zero (zero@nzeo.com) 翻訳：RisaPapa
     * @brief  日本語言語パッケージ（基本的な内容のみ）
     **/

    $lang->admin_info = '管理者情報';
    $lang->admin_index = '管理者トップページ';

    $lang->module_category_title = array(
        'service' => 'サービス型モジュール',
        'manager' => '管理型モジュール',
        'utility' => '機能性モジュール',
        'accessory' => '付加モジュール',
        'base' => '基本モジュール',
    );

    $lang->newest_news = "最新ニュース";

    $lang->env_setup = "環境設定";

    $lang->env_information = "環境情報";
    $lang->current_version = "インストールバージョン";
    $lang->current_path = "インストールパス";
    $lang->released_version = "最新バージョン";
    $lang->about_download_link = "インストールされたバージョンより新しいバージョンが配布されました。ダウンロードリンクをクリックするとダウンロードできます。";

    $lang->item_module = "モジュールリスト";
    $lang->item_addon  = "アドオンリスト";
    $lang->item_widget = "ウィジェットリスト";
    $lang->item_layout = "レイアウトリスト";

    $lang->module_name = "モジュール名";
    $lang->addon_name = "アドオン名";
    $lang->version = "バージョン";
    $lang->author = "作者";
    $lang->table_count = "テーブル数";
    $lang->installed_path = "インストールパス";

    $lang->cmd_shortcut_management = "メニュー編集";

    $lang->msg_is_not_administrator = '管理者のみ接続できます';
    $lang->msg_manage_module_cannot_delete = 'モジュール、アドオン、ウィジェットのショットカットは削除できません。';
    $lang->msg_default_act_is_null = 'デフォルトの管理者のアクションが指定されていないため、ショットカットを登録することができません。';

    $lang->welcome_to_zeroboard_xe = 'ゼロボードXEの管理者ページです。';
    $lang->about_admin_page = "管理者ページはまだ未完成です。クローズベタバージョンの期間に、多くの方々からご意見をいただきながら、必ず必要なコンテンツを埋めていきたいと思います。";
    $lang->about_lang_env = "上で設定された言語を、初めてサイトに訪問したユーザに同じく適用させるためには、希望する言語に変更してから「保存」ボタンをクリックしてください。";

    $lang->zeroboard_xe_user_links = 'ユーザのためのリンク';
    $lang->zeroboard_xe_developer_links = 'デベロッパーのためのリンク';

    $lang->xe_user_links = array(
        '公式ホームページ' => 'http://www.zeroboard.com',
        //'クローズベタサイト' => 'http://spring.zeroboard.com',
        //'モジュルダ情報' => 'http://www.zeroboard.com',
        //'アドオン情報' => 'http://www.zeroboard.com',
        //'ウィジェット情報' => 'http://www.zeroboard.com',
        //'モジュール・スキン情報' => 'http://www.zeroboard.com',
        //'ウィジェットスキン情報' => 'http://www.zeroboard.com',
        //'レイアウトスキン情報' => 'http://www.zeroboard.com',
    );

    $lang->xe_developer_links = array(
        'デベロッパーフォーラム' => 'http://spring.zeroboard.com',
        //'マニュアル' => 'http://www.zeroboard.com/wiki/manual',
        'イッシュートラッキング' => 'http://trac.zeroboard.com',
        'SVN Repository' => 'http://svn.zeroboard.com',
        'Doxygen Document' => 'http://doc.zeroboard.com',
        'PDFドキュメント' => 'http://doc.zeroboard.com/zeroboard_xe.pdf',
    );

    $lang->zeroboard_xe_usefulness_module = '有用なモジュール';
    $lang->xe_usefulness_modules = array(
        'dispEditorAdminIndex' => 'エディター管理',
        'dispDocumentAdminList' => 'ドキュメント管理',
        'dispCommentAdminList' => 'コメント管理',
        'dispFileAdminList' => '添付ファイル管理',
        'dispPollAdminList' => 'アンケート管理',
        'dispSpamfilterAdminConfig' => 'スパムフィルター管理',
        'dispCounterAdminIndex' => 'カウンターログ',

    );

    $lang->xe_license = 'ゼロボードXEのライセンスはGPLです。';
    $lang->about_shortcut = 'よく使用するモジュールに登録されたショットカットは削除できます。';
?>
